@@ -13,7 +13,7 @@ use IO::File;
 use File::Temp;
 use IPC::Run;
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 use URI::file;
 use Readonly;
@@ -21,6 +21,7 @@ use Readonly;
 use Padre::Wx ();
 use base 'Padre::Plugin';
 
+# constants for html exporting
 Readonly my $FULL_HTML    => 'full_html';
 Readonly my $SIMPLE_HTML  => 'simple_html';
 Readonly my $SNIPPET_HTML => 'snippet_html';
@@ -29,16 +30,61 @@ sub padre_interfaces {
     return 'Padre::Plugin'         => 0.20,
 }
 
+sub menu_plugins {
+    my $self        = shift;
+    my $main_window = shift;
 
-sub menu_plugins_simple {
-    my $self = shift;
-    return 'Perl 6' => [
-        'Export Full HTML' => sub { $self->export_html($FULL_HTML); },
-        'Export Simple HTML' => sub { $self->export_html($SIMPLE_HTML); },
-        'Export Snippet HTML' => sub { $self->export_html($SNIPPET_HTML); },
-        '---' => undef,
-        'About' => sub { $self->show_about },
-    ];
+    # Create a simple menu with a single About entry
+    $self->{menu} = Wx::Menu->new;
+
+    # Manual Perl 6 syntax highlighting
+    Wx::Event::EVT_MENU(
+        $main_window,
+        $self->{menu}->Append( -1, "Manual Perl 6 syntax highlighting\tCtrl-R", ),
+        sub { $self->highlight(0); },
+    );
+
+    # Toggle Auto Perl 6 syntax highlighting
+    $self->{p6_highlight} = 
+        $self->{menu}->AppendCheckItem( -1, "Automatic Perl 6 syntax highlighting",);
+    Wx::Event::EVT_MENU(
+        $main_window,
+        $self->{p6_highlight},
+        sub { $self->toggle_highlight; }
+    );
+    my $config = Padre->ide->config;
+    $self->{p6_highlight}->Check($config->{p6_highlight} ? 1 : 0);
+
+    $self->{menu}->AppendSeparator;
+
+    # export into HTML
+    Wx::Event::EVT_MENU(
+        $main_window,
+        $self->{menu}->Append( -1, 'Export Full HTML', ),
+        sub { $self->export_html($FULL_HTML); },
+    );
+    Wx::Event::EVT_MENU(
+        $main_window,
+        $self->{menu}->Append( -1, 'Export Simple HTML', ),
+        sub { $self->export_html($SIMPLE_HTML); },
+    );
+    Wx::Event::EVT_MENU(
+        $main_window,
+        $self->{menu}->Append( -1, 'Export Snippet HTML', ),
+        sub { $self->export_html($SNIPPET_HTML); },
+    );
+
+    $self->{menu}->AppendSeparator;
+
+    # the famous about menu item...
+    Wx::Event::EVT_MENU(
+        $main_window,
+        $self->{menu}->Append( -1, 'About', ),
+        sub { $self->show_about },
+    );
+
+    # Return it and the label for our plugin
+    return ( $self->plugin_name => $self->{menu} );
 }
 
 sub registered_documents {
@@ -54,11 +100,36 @@ sub show_about {
     $about->SetDescription(
         "Perl6 syntax highlighting that is based on\nSyntax::Highlight::Perl6\n"
     );
-	$about->SetVersion($VERSION);
+    $about->SetVersion($VERSION);
     Wx::AboutBox( $about );
     return;
 }
 
+sub toggle_highlight {
+    my $self = shift;
+    if(! defined $self->{p6_highlight}) {
+        return;
+    }
+    my $config = Padre->ide->config;
+    if($config->{p6_highlight}) {
+        $self->highlight;
+    }
+    $config->{p6_highlight} = $self->{p6_highlight}->IsChecked ? 1 : 0;
+}
+
+sub highlight {
+    my $self = shift;
+    my $doc = Padre::Documents->current or return;
+    
+    if ($doc->can('colorize')) {
+        my $text = $doc->text_get;
+        $doc->{_text} = $text;
+        $doc->{force_p6_highlight} = 1;
+        $doc->colorize;
+        $doc->{force_p6_highlight} = 0;
+    }
+}
+
 sub text_with_one_nl {
     my $self = shift;
     my $doc = shift;
@@ -98,7 +169,6 @@ sub export_html {
 
     # construct the command
     my @cmd = ( 'hilitep6' );
-    say "Running @cmd";
 
     my $html;
     eval {
